<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>AboutDlg</name>
    <message>
        <location filename="aboutui.ui" line="14"/>
        <source>About GPSBabel</source>
        <translation>Informazioni su GPSBabel</translation>
    </message>
    <message>
        <location filename="aboutui.ui" line="74"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:13pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt; font-weight:600;&quot;&gt;$appname$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;$babelfeversion$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;Copyright (C) 2009-2016 Robert Lipe&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;GUI designed and contributed by  S. Khai Mong&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;LGPL Crystal Icons by Elvarado Coehlo&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;(Using backend $babelversion$)&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;$upgradetestmode$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;Installation ID: $installationId$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;This program is free software; you can redistribute it and/or  modify it under the terms of the GNU General Public License as  published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111 USA&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <oldsource>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:13pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt; font-weight:600;&quot;&gt;$appname$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;$babelfeversion$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;Copyright (C) 2009-2014 Robert Lipe&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;GUI designed and contributed by  S. Khai Mong&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;LGPL Crystal Icons by Elvarado Coehlo&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;(Using backend $babelversion$)&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;$upgradetestmode$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;Installation ID: $installationId$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;This program is free software; you can redistribute it and/or  modify it under the terms of the GNU General Public License as  published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111 USA&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</oldsource>
        <translation type="unfinished">&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:13pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:600;&quot;&gt;$appname$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;$babelfeversion$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;Copyright (C) 2009 Robert Lipe&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;Interfaccia grafica disegnata e implementata da  S. Khai Mong&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;LGPL Crystal Icons di Alvarado Coehlo&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;(Uso backend $babelversion$)&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;$upgradetestmode$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;
Questo programma &amp;egrave; software libero; è possibile distribuirlo e/o modificarlo secondo i termini della GNU General Public License come  pubblicata dalla Free Software Foundation; sia la versione 2 della licenza, sia (a propria scelta) una versione successiva.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;Questo programma &amp;egrave; distribuito nella speranza che sia utile, ma SENZA ALCUNA GARANZIA; senza neppure la garanzia implicita di COMMERCIABILIT&amp;Agrave; o IDONEIT&amp;Agrave; PER UNO SCOPO PARTICOLARE.  Vedere la GNU General Public License per ulteriori dettagli.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;Si dovrebbe aver ricevuto una copia della GNU General Public License insieme a questo programma; in caso contrario, scrivere alla Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111 USA&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;
</translation>
    </message>
</context>
<context>
    <name>AdvUi</name>
    <message>
        <location filename="advui.ui" line="14"/>
        <source>Global Options</source>
        <translation>Opzioni generali</translation>
    </message>
    <message>
        <location filename="advui.ui" line="20"/>
        <source>Create smart shortened names. </source>
        <translation>Crea nomi abbreviati intelligenti. </translation>
    </message>
    <message>
        <location filename="advui.ui" line="23"/>
        <source>Synthesize short names</source>
        <translation>Sintetizza i nomi brevi</translation>
    </message>
    <message>
        <location filename="advui.ui" line="33"/>
        <source>Convert character set encoding between input and output</source>
        <translation>Converti la codifica del set di caratteri tra sorgente e destinazione</translation>
    </message>
    <message>
        <location filename="advui.ui" line="36"/>
        <source>Enable character set transformation</source>
        <translation>Abilita la trasformazione del set di caratteri</translation>
    </message>
    <message>
        <location filename="advui.ui" line="43"/>
        <source>Preview in Google Maps</source>
        <translation>Anteprima in Google Maps</translation>
    </message>
    <message>
        <location filename="advui.ui" line="52"/>
        <source>Debugging diagnostics.  
Higher number provides more deitaled diagnostics.</source>
        <translation>Diagnosi di debug.  
Un numero più alto fornisce un livello di diagnosi più dettagliato.</translation>
    </message>
    <message>
        <location filename="advui.ui" line="57"/>
        <source>None</source>
        <translation>Nessuno</translation>
    </message>
    <message>
        <location filename="advui.ui" line="62"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="advui.ui" line="67"/>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <location filename="advui.ui" line="72"/>
        <source>2</source>
        <translation>2</translation>
    </message>
    <message>
        <location filename="advui.ui" line="77"/>
        <source>3</source>
        <translation>3</translation>
    </message>
    <message>
        <location filename="advui.ui" line="82"/>
        <source>4</source>
        <translation>4</translation>
    </message>
    <message>
        <location filename="advui.ui" line="87"/>
        <source>5</source>
        <translation>5</translation>
    </message>
    <message>
        <location filename="advui.ui" line="92"/>
        <source>6</source>
        <translation>6</translation>
    </message>
    <message>
        <location filename="advui.ui" line="97"/>
        <source>7</source>
        <translation>7</translation>
    </message>
    <message>
        <location filename="advui.ui" line="102"/>
        <source>8</source>
        <translation>8</translation>
    </message>
    <message>
        <location filename="advui.ui" line="107"/>
        <source>9</source>
        <translation>9</translation>
    </message>
    <message>
        <location filename="advui.ui" line="115"/>
        <source>Debugging Diagnostics</source>
        <translation>Diagnosi di debug</translation>
    </message>
    <message>
        <location filename="advui.ui" line="139"/>
        <source>Set all format input/output options to default values</source>
        <translation>Imposta tutte le opzioni di origine/destinazione ai valori predefiniti</translation>
    </message>
    <message>
        <location filename="advui.ui" line="142"/>
        <source>Default Format Options</source>
        <translation>Opzioni predefinite dei formati</translation>
    </message>
</context>
<context>
    <name>Donate</name>
    <message>
        <location filename="donate.ui" line="32"/>
        <source>Support GPSBabel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="donate.ui" line="47"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:13pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;GPSBabel is free software built and supported by volunteers. It consumes vast amounts of time to create and support the software as well as money for mapping programs, GPS receivers, and development fixtures. Please see how you can &lt;a href=&quot;https://www.gpsbabel.org&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;contribute time or via PayPal (no account needed).&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <oldsource>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:13pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;GPSBabel is free software built and supported by volunteers. It consumes vast amounts of time to create and support the software as well as money for mapping programs, GPS receivers, and development fixtures. Please see how you can &lt;a href=&quot;http://www.gpsbabel.org&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;contribute time or via PayPal (no account needed) or Google Checkout.&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</oldsource>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="donate.ui" line="61"/>
        <source>&lt;p&gt;Of course, if you&apos;ve already contributed  to the project or you just can&apos;t help the project, please check the box below to never see this message again.&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="donate.ui" line="71"/>
        <source>Never show this message again.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="donate.ui" line="93"/>
        <source>No, Thanks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="donate.ui" line="100"/>
        <source>Contribute</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileDlgManager</name>
    <message>
        <location filename="optionsdlg.cc" line="73"/>
        <source>Select input file</source>
        <translation>Seleziona il file di origine</translation>
    </message>
    <message>
        <location filename="optionsdlg.cc" line="77"/>
        <source>Select output file</source>
        <translation>Seleziona il file di destinazione</translation>
    </message>
</context>
<context>
    <name>FilterDialog</name>
    <message>
        <location filename="filterdlg.cc" line="41"/>
        <source>Tracks</source>
        <translation>Tracce</translation>
    </message>
    <message>
        <location filename="filterdlg.cc" line="44"/>
        <source>Waypoints</source>
        <translation>Punti di interesse</translation>
    </message>
    <message>
        <location filename="filterdlg.cc" line="47"/>
        <source>Routes &amp; Tracks</source>
        <translation>Rotte e tracce</translation>
    </message>
    <message>
        <location filename="filterdlg.cc" line="50"/>
        <source>Miscellaneous</source>
        <translation>Varie</translation>
    </message>
    <message>
        <location filename="filterdlg.cc" line="104"/>
        <source>Are you sure you want to reset all filter options to default values?</source>
        <translation>Si è certi di voler reimpostare tutte le opzioni dei filtri ai valori predefiniti?</translation>
    </message>
</context>
<context>
    <name>FilterDlg</name>
    <message>
        <location filename="filterui.ui" line="14"/>
        <source>Data Filters</source>
        <translation>Filtri di dati</translation>
    </message>
    <message>
        <location filename="filterui.ui" line="17"/>
        <source>Data filters process and transform the data between input and output files or devices. </source>
        <translation>I filtri di dati processano e trasformano i dati da file/dispositivi di origine e destinazione.</translation>
    </message>
    <message>
        <location filename="filterui.ui" line="72"/>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <location filename="filterui.ui" line="83"/>
        <source>Reset</source>
        <translation>Reimposta</translation>
    </message>
</context>
<context>
    <name>GMapDialog</name>
    <message>
        <location filename="gmapdlg.cc" line="55"/>
        <source>meters</source>
        <translation>metri</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="64"/>
        <source>feet</source>
        <translation>piede</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="68"/>
        <source>miles</source>
        <translation>miglia</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="71"/>
        <source>Length: %1 %2
  %3 %4</source>
        <translation>Lunghezza: %1 %2
  %3 %4</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="81"/>
        <source>Lat: %1</source>
        <translation>Lat: %1</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="82"/>
        <source>Lng: %1</source>
        <translation>Lng: %1</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="84"/>
        <source>Desc: %1</source>
        <translation>Desc: %1</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="86"/>
        <source>Cmt: %1</source>
        <translation>Cmt: %1</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="88"/>
        <source>Ele: %1</source>
        <translation>Alt: %1</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="118"/>
        <source>Start: %1</source>
        <translation>Avvio: %1</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="120"/>
        <source>Stop: %1</source>
        <translation>Stop: %1</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="123"/>
        <source>Points: %1</source>
        <translation>Punti: %1</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="150"/>
        <source>Waypoints</source>
        <translation>Punti di interesse</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="165"/>
        <source>Tracks</source>
        <translation>Tracce</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="180"/>
        <source>Routes</source>
        <translation>Rotte</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="521"/>
        <source>Show All Waypoints</source>
        <translation>Mostra tutti i punti di interesse</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="522"/>
        <source>Hide All Waypoints</source>
        <translation>Nascondi tutti i punti di interesse</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="523"/>
        <location filename="gmapdlg.cc" line="531"/>
        <location filename="gmapdlg.cc" line="539"/>
        <source>Expand All</source>
        <translation>Espandi tutto</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="524"/>
        <location filename="gmapdlg.cc" line="532"/>
        <location filename="gmapdlg.cc" line="540"/>
        <source>Collapse All</source>
        <translation>Contrai tutto</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="529"/>
        <source>Show All Routes</source>
        <translation>Mostra tutte le rotte</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="530"/>
        <source>Hide All Routes</source>
        <translation>Nascondi tutte le rotte</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="537"/>
        <source>Show All Tracks</source>
        <translation>Mostra tutte le tracce</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="538"/>
        <source>Hide All Tracks</source>
        <translation>Nascondi tutte le tracce</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="545"/>
        <source>Show Only This Waypoint</source>
        <translation>Mostra solo questo punto di interesse</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="551"/>
        <source>Show Only This Track</source>
        <translation>Mostra solo questa traccia</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="557"/>
        <source>Show Only This Route</source>
        <translation>Mostra solo questa rotta</translation>
    </message>
</context>
<context>
    <name>GMapDlg</name>
    <message>
        <location filename="gmapui.ui" line="14"/>
        <source>Dialog</source>
        <translation>Finestra di dialogo</translation>
    </message>
    <message>
        <location filename="gmapui.ui" line="47"/>
        <source>Copy to Clipboard</source>
        <translation>Copia negli appunti</translation>
    </message>
    <message>
        <location filename="gmapui.ui" line="50"/>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>MainWindow</source>
        <translation type="obsolete">FinestraPrincipale</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="14"/>
        <source>GPSBabel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="21"/>
        <source>Input </source>
        <translation>Ingresso</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="41"/>
        <source>If selected, input is from a file.</source>
        <translation>Se selezionato, l&apos;ingresso è da file.</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="44"/>
        <location filename="mainwinui.ui" line="431"/>
        <location filename="mainwinui.ui" line="628"/>
        <source>File</source>
        <translation>File</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="57"/>
        <source>If selected, input is from a device or GPS unit</source>
        <translation>Se selezionato, l&apos;ingresso è da un dispositivo o da un&apos;unità GPS</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="60"/>
        <location filename="mainwinui.ui" line="447"/>
        <source>Device</source>
        <translation>Dispositivo</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="89"/>
        <location filename="mainwinui.ui" line="476"/>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="96"/>
        <source>Input data format</source>
        <translation>Formato dei dati in ingresso</translation>
    </message>
    <message>
        <source>Character encoding of input</source>
        <translation type="obsolete">Codifica dei caratteri dell&apos;ingresso</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="120"/>
        <source>Browse for one or more input files. </source>
        <translation>Sfoglia uno o più file d&apos;ingresso.</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="123"/>
        <source>File Name(s)</source>
        <translation>Nome/i di file</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="155"/>
        <location filename="mainwinui.ui" line="539"/>
        <source>Device Name:</source>
        <translation>Nome del dispositivo:</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="162"/>
        <source>Name of port to which input device is connected</source>
        <translation>Nome della porta cui è connesso il dispositivo d&apos;ingresso</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="193"/>
        <source>Options for the selected input format. </source>
        <translation>Opzioni per il formato d&apos;ingresso selezionato.</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="196"/>
        <location filename="mainwinui.ui" line="580"/>
        <source>Options</source>
        <translation>Opzioni</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="221"/>
        <source>Translation Options</source>
        <translation>Opzioni di traduzione</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="230"/>
        <location filename="mainwinui.ui" line="273"/>
        <location filename="mainwinui.ui" line="313"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="240"/>
        <source>If selected, translate waypoints.</source>
        <translation>Se selezionato, traduce i punti di interesse.</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="243"/>
        <source>Waypoints</source>
        <translation>Punti di interesse</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="280"/>
        <source>If selected, translate routes.</source>
        <translation>Se selezionato, traduce le rotte.</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="283"/>
        <source>Routes</source>
        <translation>Rotte</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="320"/>
        <source>If selected, translate tracks.</source>
        <translation>Se selezionato, traduce le tracce.</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="323"/>
        <source>Tracks</source>
        <translation>Tracce</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="359"/>
        <source>Data Filters between input and output</source>
        <translation>Filtri di dati tra sorgente e destinazione</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="362"/>
        <source>Filters</source>
        <translation>Filtri</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="395"/>
        <source>More translation options. </source>
        <translation>Altre opzioni di traduzione.</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="398"/>
        <source>More Options</source>
        <translation>Altre opzioni</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="408"/>
        <source>Output</source>
        <translation>Destinazione</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="428"/>
        <source>If selected, output is to a file. </source>
        <translation>Se selezionato, la destinazione è un file.</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="444"/>
        <source>If selected, output is to a device or GPS unit</source>
        <translation>Se selezionato, la destinazione è un dispositivo o un&apos;unità GPS</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="483"/>
        <source>Output data format.</source>
        <translation>Formato dei dati di destinazione.</translation>
    </message>
    <message>
        <source>Character encoding of output</source>
        <translation type="obsolete">Codifica dei caratteri della destinazione</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="504"/>
        <source>Browse for an output file name. </source>
        <translation>Seleziona il nome del file di destinazione.</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="507"/>
        <source>File Name</source>
        <translation>Nome del file</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="546"/>
        <source>Name of port to which output device is connected</source>
        <translation>Nome della porta cui è connesso il dispositivo di destinazione</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="577"/>
        <source>Options for the selected output format. </source>
        <translation>Opzioni per il formato di destinazione selezionato.</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="601"/>
        <source>Output of GPSBabel translation process. </source>
        <translation>Risultato del processo di traduzione di GPSBabel.</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="635"/>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="651"/>
        <source>GPSBabel Help</source>
        <translation>Aiuto di GPSBabel</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="656"/>
        <source>About GPSBabel</source>
        <translation>Informazioni su GPSBabel</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="661"/>
        <source>Quit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="666"/>
        <source>Preferences...</source>
        <translation>Preferenze...</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="671"/>
        <source>Check for Upgrade</source>
        <translation>Controlla aggiornamenti</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="676"/>
        <source>Visit Website...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="681"/>
        <source>Make a Donation...</source>
        <translation></translation>
    </message>
    <message>
        <source>default</source>
        <translation type="obsolete">predefinite</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="528"/>
        <source>Select one or more input files</source>
        <translation>Selezionare uno o più file in ingresso</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="555"/>
        <source>Output File Name</source>
        <translation>Nome del file in uscita</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="615"/>
        <source>Error reading format configuration.  Check that the backend program &quot;gpsbabel&quot; is properly installed and is in the current PATH

This program cannot continue.</source>
        <translation>Errore durante la lettura del formato della configurazione.  Verificare che il programma backend &quot;gpsbabel&quot; sia installato correttamente e che sia nel percorso corrente (variabile PATH)

Questo programma non può proseguire.</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="626"/>
        <source>Some file/device formats were not found during initialization.  Check that the backend program &quot;gpsbabel&quot; is properly installed and is in the current PATH

This program cannot continue.</source>
        <translation>Qualche formato di file/dispositivo non è stato trovato durante l&apos;inizializzazione.  Verifica che il programma di backend &quot;gpsbabel&quot; sia correttamente installato e che sia nel PATH corrente

Questo programma non può proseguire.</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="648"/>
        <source>Input and output formats do not support %1</source>
        <translation>I formati di ingresso e di uscita non supportano %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="651"/>
        <source>Input does not support %1; output format supports %2</source>
        <translation>L&apos;ingresso non supporta %1, il formato di destinazione supporta %2</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="654"/>
        <source>Input format supports %1; output format does not support %2</source>
        <translation>Il formato in ingresso supporta %1, il formato di destinazione non supporta %2</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="657"/>
        <source>Both input and output formats support %1</source>
        <translation>I formati di origine e di destinazione supportano %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="678"/>
        <source>waypoints</source>
        <translation>punti di interesse</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="679"/>
        <source>tracks</source>
        <translation>tracce</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="680"/>
        <source>routes</source>
        <translation>rotte</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="770"/>
        <source>There are no input options for format &quot;%1&quot;</source>
        <translation>Non ci sono opzioni in ingresso per il formato &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="777"/>
        <location filename="mainwindow.cc" line="797"/>
        <source>Options for %1</source>
        <translation>Opzioni per %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="790"/>
        <source>There are no output options for format &quot;%1&quot;</source>
        <translation>Non ci sono opzioni in uscita per il formato &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="811"/>
        <source>No valid waypoints/routes/tracks translation specified</source>
        <translation>Non è stato specificato alcun punto di interesse/rotta/traccia</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="830"/>
        <source>No input file specified</source>
        <translation>Il file di origine non è stato specificato</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="837"/>
        <source>No valid output specified</source>
        <translation>Non è stata specificata una destinazione valida</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="842"/>
        <source>No output file specified</source>
        <translation>Il file di destinazione non è stato specificato</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="858"/>
        <source>Process &quot;%1&quot; did not start</source>
        <translation>Il processo &quot;%1&quot; non è stato avviato</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="872"/>
        <source>Process exited unsucessfully with code %1</source>
        <translation>Il processo è terminato con il codice di errorre %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="1007"/>
        <source>Translation successful</source>
        <translation>Traduzione terminata con successo</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="1018"/>
        <source>Error running gpsbabel: %1
</source>
        <translation>Errore durante l&apos;esecuzione di gpsbabel: %1
</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="1132"/>
        <source>Are you sure you want to reset all format options to default values?</source>
        <translation>Si è certi di voler reimpostare tutte le opzioni dei formati ai valori predefiniti?</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="1155"/>
        <source>About %1</source>
        <translation>Informazioni su %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="1198"/>
        <source>One or more data filters are active</source>
        <translation>È attivo uno o più filtri di dati</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="1200"/>
        <source>No data filters are active</source>
        <translation>Nessun filtro di dati è attivo</translation>
    </message>
</context>
<context>
    <name>Map</name>
    <message>
        <location filename="map.cc" line="76"/>
        <source>Missing &quot;gmapbase.html&quot; file.  Check installation</source>
        <translation>Il file &quot;gmapbase.html&quot; manca. Verifica l&apos;installazione</translation>
    </message>
    <message>
        <location filename="map.cc" line="96"/>
        <source>Failed to load Google maps base page</source>
        <translation>Non è stato possibile caricare la pagina di base delle mappe di Google</translation>
    </message>
</context>
<context>
    <name>MiscFltWidget</name>
    <message>
        <location filename="miscfltui.ui" line="14"/>
        <source>Form</source>
        <translation>Modulo</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="27"/>
        <source>Misc. Filters</source>
        <translation>Filtri vari</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="34"/>
        <source>Nuke (Remove) Data Types</source>
        <translation>Rimuovi tipi di dati</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="46"/>
        <location filename="filterwidgets.cc" line="222"/>
        <location filename="filterwidgets.cc" line="223"/>
        <location filename="filterwidgets.cc" line="224"/>
        <location filename="filterwidgets.cc" line="225"/>
        <source>Routes</source>
        <translation>Rotte</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="53"/>
        <location filename="filterwidgets.cc" line="221"/>
        <location filename="filterwidgets.cc" line="222"/>
        <location filename="filterwidgets.cc" line="225"/>
        <location filename="filterwidgets.cc" line="226"/>
        <source>Tracks</source>
        <translation>Tracce</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="60"/>
        <location filename="filterwidgets.cc" line="221"/>
        <location filename="filterwidgets.cc" line="223"/>
        <location filename="filterwidgets.cc" line="224"/>
        <location filename="filterwidgets.cc" line="226"/>
        <source>Waypoints</source>
        <translation>Punti di interesse</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="72"/>
        <source>Convert routes, waypoints and tracks to different types.</source>
        <translation>Converti rotte, punti di interesse e tracce in tipi differenti.</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="75"/>
        <source>This filter can be used to convert GPS data between different data types.

Some GPS data formats support only some subset of waypoints, tracks, and routes. The transform filter allows you to convert between these types. For example, it can be used to convert a pile of waypoints (such as those from a CSV file) into a track or vice versa. </source>
        <translation>Questo filtro può essere usato per convertire dati GPS tra diversi tipi di dati.

Qualche formato di dati del GPS supporta solo un sottoinsieme di punti di interesse, tracce e rotte. Il filtro di trasformazione permette la conversione tra questi tipi. Per esempio, può essere usato per convertire un insieme di punti di interesse (per esempio da un file CSV) in una traccia (o viceversa).</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="80"/>
        <source>Transform</source>
        <translation>Trasforma</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="87"/>
        <source>Type of transformation. </source>
        <translation>Tipo di trasformazione.</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="94"/>
        <source>Delete original data after transform to prevent duplicated data. </source>
        <translation>Elimina i dati originali dopo la trasformazione per evitare dati duplicati.</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="97"/>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="119"/>
        <source>Swap Longitude and Latitudes for badly formatted data formats.</source>
        <translation>Scambia longitudine e latitudine per i formati di data malformati.</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="122"/>
        <source>Simple filter to swap the coordinate values (latitude and longitude) of all points. This can be helpful for wrong defined/coded data. Or if you think, you can use one of our xcsv formats, but latitude and longitude are in opposite order. </source>
        <translation>Semplice filtro per scambiare i valori delle coordinate (latitudine e longitudine) di tutti i punti. Può essere utile nel caso di dati malformati. O, se preferisci, puoi usare uno dei nostri formati xcsv, ma latitudine e longitudine sono scambiate.</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="125"/>
        <source>Swap Coordinates</source>
        <translation>Scambia le coordinate</translation>
    </message>
</context>
<context>
    <name>OptionsDlg</name>
    <message>
        <location filename="optionsdlg.cc" line="192"/>
        <location filename="optionsdlg.cc" line="203"/>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
</context>
<context>
    <name>Preferences</name>
    <message>
        <location filename="preferences.ui" line="20"/>
        <source>GPSBabel Preferences</source>
        <translation>Preferenze di GPSBabel</translation>
    </message>
    <message>
        <location filename="preferences.ui" line="30"/>
        <source>General</source>
        <translation>Generali</translation>
    </message>
    <message>
        <location filename="preferences.ui" line="45"/>
        <source>Check for newer version on start.</source>
        <translation>Verifica nuove versioni all&apos;avvio.</translation>
    </message>
    <message>
        <location filename="preferences.ui" line="52"/>
        <source>Anonymously report usage data.</source>
        <translation>Trasmetti informazioni anonime sull&apos;utilizzo.</translation>
    </message>
    <message>
        <location filename="preferences.ui" line="59"/>
        <source>Ignore mismatch between command line and GUI version.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="preferences.ui" line="68"/>
        <source>Formats</source>
        <translation>Formati</translation>
    </message>
    <message>
        <location filename="preferences.ui" line="76"/>
        <source>Enabled Formats</source>
        <translation>Formati abilitati</translation>
    </message>
    <message>
        <location filename="preferences.ui" line="100"/>
        <source>Enable All</source>
        <translation>Abilita tutti</translation>
    </message>
    <message>
        <location filename="preferences.ui" line="107"/>
        <source>Disable All</source>
        <translation>Disabilita tutti</translation>
    </message>
</context>
<context>
    <name>ProcessWaitDialog</name>
    <message>
        <location filename="processwait.cc" line="43"/>
        <source>Process failed to start</source>
        <translation>Si è verificato un errore durante l&apos;avvio del processo</translation>
    </message>
    <message>
        <location filename="processwait.cc" line="46"/>
        <source>Process crashed</source>
        <translation>Il processo si è interrotto</translation>
    </message>
    <message>
        <location filename="processwait.cc" line="49"/>
        <source>Process timedout</source>
        <translation>Il processo non è terminato entro il tempo limite</translation>
    </message>
    <message>
        <location filename="processwait.cc" line="52"/>
        <source>Error while trying to write to process</source>
        <translation>Errore durante la scrittura nel processo</translation>
    </message>
    <message>
        <location filename="processwait.cc" line="55"/>
        <source>Error while trying to read from process</source>
        <translation>Errore durante la lettura dal processo</translation>
    </message>
    <message>
        <location filename="processwait.cc" line="59"/>
        <source>Unknown process error</source>
        <translation>Errore sconosciuto nel processo</translation>
    </message>
    <message>
        <location filename="processwait.cc" line="68"/>
        <source> ... Process GPSBabel</source>
        <translation>... processo GPSBabel</translation>
    </message>
    <message>
        <location filename="processwait.cc" line="83"/>
        <source>Stop Process</source>
        <translation>Arresta il processo</translation>
    </message>
    <message>
        <location filename="processwait.cc" line="155"/>
        <source>Process did not terminate successfully</source>
        <translation>Il processo non è terminato correttamente</translation>
    </message>
    <message>
        <location filename="processwait.cc" line="174"/>
        <source>Process crashed whle running</source>
        <translation>Il processo si è interrotto</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="formatload.cc" line="155"/>
        <source>Error processing formats from running process &quot;gpsbabel -^3&quot; at line %1</source>
        <translation>Si è verificato un errore durante l&apos;elaborazione dei formati da parte del processo di lavoro &quot;gpsbabel -^3&quot; alla linea %1</translation>
    </message>
</context>
<context>
    <name>RtTrkWidget</name>
    <message>
        <location filename="rttrkui.ui" line="14"/>
        <source>Form</source>
        <translation>Modulo</translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="17"/>
        <source>Simplify routes and tracks by removing points</source>
        <translation>Semplifica rotte e tracce mediante rimozione di punti</translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="20"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;The Simplify filter is used to simplify routes and tracks for use with formats that limit the number of points they can contain or just to reduce the complexity of a route. &lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;The filter attempts to remove points from each route until the number of points or the error is within the given bounds, while also attempting to preserve the shape of the original route as much as possible. &lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;The quality of the results will vary depending on the density of points in the original route and the length of the original route. &lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;margin-top:12px;margin-bottom:12px;margin-left:0px;margin-right:0px;-qt-block-indent:0;text-indent:0px;&quot;&gt;Il filtro di semplificazione viene usato per semplificare rotte e tracce per l&apos;uso con formati che supportano un limitato numero di punti o semplicemente per ridurre la complessit&amp;agrave; di una rotta.&lt;/p&gt;
&lt;p style=&quot;margin-top:12px;margin-bottom:12px;margin-left:0px;margin-right:0px;-qt-block-indent:0;text-indent:0px;&quot;&gt;Il filtro prova a rimuovere i punti da ogni rotta finch&amp;acute; il numero di punti o l&apos;errore ricade entro i limiti forniti, cercando nel contempo di mantenere per quanto possibile la forma della rotta originale.&lt;/p&gt;
&lt;p style=&quot;margin-top:12px;margin-bottom:12px;margin-left:0px;margin-right:0px;-qt-block-indent:0;text-indent:0px;&quot;&gt;La qualit&amp;agrave; dei risultati dipender&amp;agrave; dalla densit&amp;agrave; dei punti e dalla lunghezza della rotta originale.&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty;margin-top:0px;margin-bottom:0px;margin-left:0px;margin-right:0px;-qt-block-indent:0;text-indent:0px;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="40"/>
        <source>Routes &amp; Tracks</source>
        <translation>Rotte e tracce</translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="49"/>
        <source>Simplify route by removing points</source>
        <translation>Semplifica la rotta mediante la rimozione di punti</translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="52"/>
        <source> The Simplify filter is used to simplify routes and tracks for use with formats that limit the number of points they can contain or just to reduce the complexity of a route.

The filter attempts to remove points from each route until the number of points or the error is within the given bounds, while also attempting to preserve the shape of the original route as much as possible.

The quality of the results will vary depending on the density of points in the original route and the length of the original route. </source>
        <translation> Il filtro di semplificazione viene usato per semplificare rotte e tracce per l&apos;uso con formati che supportano un limitato numero di punti o semplicemente per ridurre la complessità di una rotta.

Il filtro prova a rimuovere i punti da ogni rotta finché il numero di punti o l&apos;errore ricade entro i limiti forniti, cercando nel contempo di mantenere per quanto possibile la forma della rotta originale.

La qualità dei risultati dipenderà dalla densità dei punti e dalla lunghezza della rotta originale. </translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="59"/>
        <source>Simplify</source>
        <translation>Semplifica</translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="82"/>
        <source>Limit To</source>
        <translation>Limita a</translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="89"/>
        <source>Maximum number points in track or route. </source>
        <translation>Numero massimo di punti nella traccia o rotta. </translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="96"/>
        <source>Points</source>
        <translation>Punti</translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="118"/>
        <source>Reverse tracks and routes</source>
        <translation>Inverti e rotte</translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="121"/>
        <source>The reversal is performed in the laziest way possible. Timestamps are kept with the original waypoints so the resulting track or route will have the interesting characteristic that time runs backwards. This tends to make Magellan Mapsend, in particular, do a wierd thing and place each waypoint on a separate day. 
Additionally, if you&apos;re using this to reverse a route that navigates, say, an exit ramp or a one way street, you will be in for unpleasant ride. application cares about timestamps </source>
        <translation>L&apos;inversione è effettuata nel modo più pigro possibile. Date ed ore sono mantenute con i punti di interesse originali in modo che la traccia o rotta risultante avrà la caratteristica interessante che il tempo scorre all&apos;indietro. Questo comporta, in particolare, che Magellan MapSend si comporti in modo strano e inserisca ogni punti di interesse in un giorno diverso.
Inoltre, se stai usando questa operazione per invertire una rotta che percorre, ad esempio, una rampa di uscita o una strada a senso unico, potrai incappare in un giro poco piacevoli. L&apos;applicazione si preoccupa di data e ora</translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="125"/>
        <source>Reverse</source>
        <translation>Inverti</translation>
    </message>
</context>
<context>
    <name>TrackWidget</name>
    <message>
        <location filename="trackui.ui" line="14"/>
        <source>Track Filter Options</source>
        <translation>Opzioni del filtro traccia</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="17"/>
        <source>This filter performs various operations on track data. </source>
        <translation>Questo filtro esegue varie operazioni sui dati delle tracce.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="35"/>
        <source>Track Filters</source>
        <translation>Filtri delle tracce</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="42"/>
        <source>Basic title for track</source>
        <translation>Titolo base della traccia</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="45"/>
        <source>Basic title for new track(s). 
This option specifies a title for tracks generated by the track filter. By default, the title of the new track is composed of the start time of the track appended to this value. 
If this value contains a percent (%) character, it is treated as a format string for the POSIX strftime function, allowing custom time-based track names. </source>
        <translation>Titolo base per nuove tracce. 
Questa opzione specifica un titolo per le tracce generate dal filtro traccia. Come impostazione predefinita, il tutolo di una nuova traccia è composto dall&apos;ora di avvio della traccia aggiunto a questo valore. 
Se questo valore contiene un simbolo percentuale (%), questo viene trattato come stringa di formato per la funzione POSIX strftime, permettendo nomi di tracce personalizzati in base all&apos;ora. </translation>
    </message>
    <message>
        <location filename="trackui.ui" line="50"/>
        <source>Title</source>
        <translation>Titolo</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="57"/>
        <source>the title of the new track is composed of the start time of the track appended to this value. </source>
        <translation>il titolo della nuova traccia è composto dall&apos;ora di avvio della traccia aggiunto a questo valore. </translation>
    </message>
    <message>
        <location filename="trackui.ui" line="64"/>
        <source>Correct track point timestamps by specified amount</source>
        <translation>Correggi date ed ore dei punti traccia di un valore specifico</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="67"/>
        <source>Correct trackpoint timestamps by a delta. 
This option changes the time of all trackpoints. This might be useful if your track must be moved by one or more hours because of an incorrect time zone. </source>
        <translation>Corregge date e ore dei punti traccia aggiungento /sottraendo un certo valore. 
Questa opzione modifica la data/l&apos;ora di tutti i punti traccia. Può essere utile se la tua traccia deve essere spostata di una o più ore per un&apos;impostazione errata del fuso orario. </translation>
    </message>
    <message>
        <location filename="trackui.ui" line="71"/>
        <source>Move</source>
        <translation>Sposta</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="83"/>
        <location filename="trackui.ui" line="275"/>
        <source>days</source>
        <translation>giorni</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="97"/>
        <source>hours</source>
        <translation>ore</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="111"/>
        <location filename="trackui.ui" line="265"/>
        <source>mins</source>
        <translation>minuti</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="125"/>
        <source>secs</source>
        <translation>secondi</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="140"/>
        <location filename="trackui.ui" line="155"/>
        <source>Use track pts. after this time. </source>
        <translation>Usa i punti traccia dopo quest&apos;ora. </translation>
    </message>
    <message>
        <location filename="trackui.ui" line="143"/>
        <source>Use only track points after this timestamp.

This option is used along with the stop to discard trackpoints that were recorded outside of a specific period of time. This option specifies the beginning of the time period. </source>
        <translation>Usa solo i punti traccia successivi a questa data/ora.

Questa opzione viene usata congiuntamente con lo stop per scartare i punti traccia che sono stati salvati al di fuori di uno specifico intervallo temporale. Questa opzione specifica l&apos;inizio dell&apos;intervallo temporale.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="148"/>
        <source>Start</source>
        <translation>Inizio</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="162"/>
        <source>If checked, time specified here is based on this computer&apos;s current time zone. </source>
        <translation>Se selezionato, l&apos;ora indicata qui è basata sul fuso orario impostato nel PC. </translation>
    </message>
    <message>
        <location filename="trackui.ui" line="165"/>
        <source>If checked, the times specified here are based on the local computer&apos;s time zone.  Otherwise it is UTC.</source>
        <translation>Se selezionato, gli orari specificati qui sono basati sul fuso orario del computer.  Altrimenti saranno in UTC (fuso di Greenwich).</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="168"/>
        <source>Local Time</source>
        <translation>Tempo locale</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="181"/>
        <location filename="trackui.ui" line="196"/>
        <source>Use track pts before this time. </source>
        <translation>Usa i punti traccia prima di quest&apos;ora. </translation>
    </message>
    <message>
        <location filename="trackui.ui" line="184"/>
        <source> Use only track points before this timestamp.

This option is used in conjunction with the start option to discard all trackpoints outside of a given period of time. This option defines the end of the time period. </source>
        <translation>Usa solo i punti traccia precedenti a questa data/ora.

Questa opzione viene usata congiuntamente con l&apos;inizio per scartare i punti traccia che sono stati salvati al di fuori di uno specifico intervallo temporale. Questa opzione specifica la fine dell&apos;intervallo temporale. </translation>
    </message>
    <message>
        <location filename="trackui.ui" line="189"/>
        <source>Stop</source>
        <translation>Fine</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="203"/>
        <source>Pack all tracks into one. </source>
        <translation>Concatena tutte le tracce in una. </translation>
    </message>
    <message>
        <location filename="trackui.ui" line="206"/>
        <source>Pack all tracks into one.

This option causes all tracks to be appended to one another to form a single track. This option does not work if any two tracks overlap in time; in that case, consider using the merge option.

This option is most useful for rejoining tracks that might have been interrupted by an equipment malfunction or an overnight stop. </source>
        <translation>Concatena tutte le tracce in una.

Questa opzione fa in modo che tutte le tracce vengano unite per formarne una sola. Questa opzione non funziona se due tracce si sovrappongono temporalmente: in quel caso prova ad utilizzare l&apos;opzione unisci.

Questa opzione è utile soprattutto per unire tracce che si sono interrotte per un malfunzionamento del dispositivo o per un arresto notturno. </translation>
    </message>
    <message>
        <location filename="trackui.ui" line="213"/>
        <source>Pack</source>
        <translation>Concatena</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="220"/>
        <source>Merge multiple tracks for the same way.</source>
        <translation>Unisci più tracce per la stessa strada.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="223"/>
        <source> Merge multiple tracks for the same way.

This option puts all track points from all tracks into a single track and sorts them by time stamp. Points with identical time stamps will be dropped. </source>
        <translation> Unisce più tracce per la stessa strada.

Questa opzione inserisce tutti i punti di ogni traccia in una singola traccia e li ordina in base all&apos;orario. I punti con lo stesso orario saranno tralasciati. </translation>
    </message>
    <message>
        <location filename="trackui.ui" line="228"/>
        <source>Merge</source>
        <translation>Unisci</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="235"/>
        <source>Split by Date</source>
        <translation>Suddividi per data</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="242"/>
        <source>Split by Time</source>
        <translation>Suddividi per ora</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="254"/>
        <source>If nonzero, the track will be split if the time between two points is greater than this parameter.   If zero, the track will be split by date. </source>
        <translation>Se diverso da zero, la traccia verrà suddivisa se il tempo tra due punti è maggiore di questo parametro.   Se zero, la traccia verrà suddivisa in base al giorno. </translation>
    </message>
    <message>
        <location filename="trackui.ui" line="270"/>
        <source>hrs</source>
        <translation>ore</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="285"/>
        <source>Split by Dist.</source>
        <translation>Suddividi per distanza</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="297"/>
        <source>If nonzero, the input track will be split into several tracks if the distance between successive track points is greater than the distance given as a parameter. </source>
        <translation>Se non zero, la traccia in ingresso verrà suddivisa in più tracce se la distanza tra punti traccia successivi è maggiore della distanza specificata nel parametro. </translation>
    </message>
    <message>
        <location filename="trackui.ui" line="308"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="313"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="318"/>
        <source>km</source>
        <translation>km</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="323"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="341"/>
        <source>GPS Fixes</source>
        <translation>Stato del GPS</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="349"/>
        <source>none</source>
        <translation>nessuno</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="354"/>
        <source>pps</source>
        <translation>pps</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="359"/>
        <source>dgps</source>
        <translation>dgps</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="364"/>
        <source>3d</source>
        <translation>3d</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="369"/>
        <source>2d</source>
        <translation>2d</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="392"/>
        <source>Synthesize speed. </source>
        <translation>Sintetizza la velocità. </translation>
    </message>
    <message>
        <location filename="trackui.ui" line="395"/>
        <source>Synthesize speed.

This option computes a value for the GPS speed at each trackpoint. This is most useful with trackpoints from formats that don&apos;t support speed information or for trackoints synthesized by the interpolate filter. The speed at each trackpoint is the average speed from the previous trackpoint (distance divided by time). The first trackpoint in each track is assigned a speed of &quot;unknown.&quot; </source>
        <translation>Sintetizza la velocità.

Questa opzione calcola il valore della velocità GPS in ogni punto traccia. Risulta utile soprattutto con punti traccia tratti da un formato che non specifica informazioni sulla velocità o da punti traccia sintetizzati dal filtro di interpolazione. La velocità in ogni punto traccia è la velocità media calcolata dal punto precedente (distanza diviso il tempo). Al primo punto di ogni traccia viene assegnata una velocità &quot;sconosciuta.&quot; </translation>
    </message>
    <message>
        <location filename="trackui.ui" line="400"/>
        <source>Speed</source>
        <translation>Velocità</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="407"/>
        <source>Synthesize course.</source>
        <translation>Sintetizza la direzione.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="410"/>
        <source>Synthesize course.

This option computes (or recomputes) a value for the GPS heading at each trackpoint. This is most useful with trackpoints from formats that don&apos;t support heading information or for trackpoints synthesized by the interpolate filter. The heading at each trackpoint is simply the course from the previous trackpoint in the track. The first trackpoint in each track is arbitrarily assigned a heading of 0 degrees. </source>
        <translation>Sintetizza la direzione.

Questa opzione calcola (o ricalcola) un valore per la direzione del GPS in ogni punto traccia. Risulta utile soprattutto con punti traccia tratti da un formato che non specifica informazioni sulla direzione o da punti traccia sintetizzati dal filtro di interpolazione. La direzione in ogni punto traccia è tratta semplicemente dalla posizione del punto traccia precedente nella traccia stessa. Al primo punto di ogni traccia viene arbitrariamente assegnato un valore pari a 0 gradi. </translation>
    </message>
    <message>
        <location filename="trackui.ui" line="415"/>
        <source>Course</source>
        <translation>Direzione</translation>
    </message>
</context>
<context>
    <name>Upgrade</name>
    <message>
        <location filename="upgrade.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialogo</translation>
    </message>
</context>
<context>
    <name>UpgradeCheck</name>
    <message>
        <location filename="upgrade.cc" line="234"/>
        <location filename="upgrade.cc" line="238"/>
        <location filename="upgrade.cc" line="272"/>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <location filename="upgrade.cc" line="235"/>
        <source>Unexpected reply.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="upgrade.cc" line="239"/>
        <source>Download failed: %1.</source>
        <translation>Scaricamento non riuscito: %1.</translation>
    </message>
    <message>
        <location filename="upgrade.cc" line="273"/>
        <source>Download failed: %1: %2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="upgrade.cc" line="289"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="upgrade.cc" line="290"/>
        <source>Invalid return data at line %1: %2.</source>
        <translation>Dati ricevuti non validi alla linea %1: %2.</translation>
    </message>
    <message>
        <location filename="upgrade.cc" line="331"/>
        <source>A new version of GPSBabel is available.&lt;br /&gt;Your version is %1 &lt;br /&gt;The latest version is %2</source>
        <translation>È disponibile una nuova versione di GPSBabel.&lt;br /&gt;Versione corrente: %1 &lt;br /&gt;Nuova versione: %2</translation>
    </message>
    <message>
        <location filename="upgrade.cc" line="342"/>
        <source>Upgrade</source>
        <translation>Aggiorna</translation>
    </message>
    <message>
        <location filename="upgrade.cc" line="349"/>
        <source>Do you wish to download an upgrade?</source>
        <translation>Si desidera scaricare un aggiornamento?</translation>
    </message>
</context>
<context>
    <name>VersionMismatch</name>
    <message>
        <location filename="version_mismatch.ui" line="32"/>
        <source>GPSBabel Version Mismatch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="version_mismatch.ui" line="38"/>
        <source>&lt;b&gt;A version mismatch has been detected.&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="version_mismatch.ui" line="47"/>
        <source>GPSBabel command line version:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="version_mismatch.ui" line="81"/>
        <source>GPSBabel GUI version:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="version_mismatch.ui" line="115"/>
        <source>Never show this message again.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WayPtsWidget</name>
    <message>
        <location filename="wayptsui.ui" line="14"/>
        <source>Form</source>
        <translation>Modulo</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="29"/>
        <source>Waypoints Filters</source>
        <translation>Filtri dei punti di interesse</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="36"/>
        <source>Remove duplicates</source>
        <translation>Rimuovi i duplicati</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="39"/>
        <source>The duplicate filter is designed to remove duplicate points based on their short name (traditionally a waypoint&apos;s name on the GPS receiver), and/or their location (to a precision of 6 decimals). This filter supports two options that specify how duplicates will be recognized, shortname and location. Generally, at least one of these options is required. </source>
        <translation>Il filtro dei duplicati è studiato per rimuovere i punti duplicati in base al loro nome breve (tipicamente un nome del punto di interesse sul ricevitore GPS), e/o in base alla posizione (con una precisione di 6 decimali). Questo filtro supporta due opzioni che indicano come individuare i duplicati, nome breve e posizione. In genere è necessario specificare almeno una di queste opzioni. </translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="42"/>
        <source>Duplicates</source>
        <translation>Duplicati</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="55"/>
        <source>Suppress duplicate waypoints based on name.</source>
        <translation>Rimuovi i punti di interesse in base al nome.</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="58"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Suppress duplicate waypoints based on name. &lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;This option is the one most often used with the duplicate filter. This option instructs the duplicate filter to remove any waypoints that share a short name with a waypoint that has come before. This option might be used to remove duplicates if you are merging two datasets that were each created in part from a common ancestor dataset. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Rimuovi i punti di interesse in base al nome. &lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Questa opzione è la più usata col filtro dei duplicati. Indica al filtro dei duplicaati di rimuovere qualsiasi punto di interesse con un nome breve condiviso con un puntio di interesse già analizzato. Questa opzione può essere usata per rimuovere i duplicati se stai unendo due serie di dati che sono state create partendo dalla stessa una serie di dati iniziale. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="66"/>
        <source>Short Names</source>
        <translation>Nomi brevi</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="73"/>
        <source>Suppress duplicate waypoint based on coords. </source>
        <translation>Rimuovi i punti di interesse in base alle coordinate. </translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="76"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Suppress duplicate waypoint based on coords. &lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;This option causes the duplicate filter to remove any additional waypoint that has the same coordinates (to six decimal degrees) as a waypoint that came before. This option may be used to remove duplicate waypoints if the names are not expected to be the same. It also might be used along with the &lt;span style=&quot; font-family:&apos;Courier New,courier&apos;;&quot;&gt;shortname&lt;/span&gt; option to remove duplicate waypoints if the names of several unrelated groups of waypoints might be the same. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Rimuovi i punti di interesse in base alle coordinate. &lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Questa opzione fa sì che il filtro dei duplicati rimuova ogni ulteriore punto di interesse avente le stesse coordinate (con una precisione di sei cifre decimali). Questa opzione può essere usata per rimuovere punti di interesse duplicati anche quando i nomi non coincidono. Puà essere usata anche congiuntamente all&apos;opzione &lt;span style=&quot; font-family:&apos;Courier New,courier&apos;;&quot;&gt;bomi brevi&lt;/span&gt; per rimuovere punti di interesse se i nomi di diversi gruppi indipendenti di punti di interesse potrebbero coincidere. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="84"/>
        <source>Locations</source>
        <translation>Posizioni</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="91"/>
        <source>Remove points based on proximity</source>
        <translation>Rimuovi i punti in base alla vicinanza</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="94"/>
        <source>Maximum positional distance.

This option specifies the minimum allowable distance between two points. If two points are closer than this distance, only one of them is kept. </source>
        <translation>Massima distanza di posizione.

Questa opzione specifica la distanza minima consentita tra due punti. Se due punti sono più vicini di questa distanza, solo uno di essi viene mantenuto. </translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="99"/>
        <source>Position</source>
        <translation>Posizione</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="112"/>
        <source>Maximum positional distance.</source>
        <translation>Massima distanza di posizione.</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="120"/>
        <source>Feet</source>
        <translation>Piedi</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="125"/>
        <source>Meters</source>
        <translation>Metri</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="133"/>
        <source>Include points only within radius</source>
        <translation>Includi punto solo entro una distanza</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="136"/>
        <source>This filter includes or excludes waypoints based on their proximity to a central point. All waypoints more than the specified distance from the specified point will be removed from the dataset.

By default, all remaining points are sorted so that points closer to the center appear earlier in the output file. </source>
        <translation>Questo filtro include o esclude i punti di interesse in funzione della loro distanza da un punto centrale. Tutti i punti di interesse con una distanza superiore a quella indicata dal punto specificato saranno rimossi dalla serie di dati.

Per impostazione predefinita, tutti gli altri punti sono ordinati in modo che i punti più vicini al centro vengano prima nel file di destinazione.</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="141"/>
        <source>Radius</source>
        <translation>Raggio</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="154"/>
        <source>Maximum distance from center. </source>
        <translation>Distanza massima dal centro.</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="162"/>
        <source>Miles</source>
        <translation>Miglia</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="167"/>
        <source>km</source>
        <translation>km</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="175"/>
        <source>Lat.</source>
        <translation>Lat.</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="188"/>
        <source>Latitude of the central point in decimal degrees.  South latitudes should be expressed as a negative number.</source>
        <translation>Latitudine del punto centrale in gradi decimali. Le latitudini dell&apos;emisfero sud vanno inserite come un numero negativo.</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="195"/>
        <source>Long.</source>
        <translation>Long.</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="208"/>
        <source>Longitude of the central point in decimal degrees. West longitudes should be expressed as a negative number.</source>
        <translation>Longitudine del punto centrale in gradi decimali. Le latitudini dell&apos;emisfero occidentale vanno inserite come un numero negativo.</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="215"/>
        <location filename="wayptsui.ui" line="218"/>
        <source>This filter sorts waypoints into alphabetical order</source>
        <translation>Questo filtro ordina i punti di interesse in ordine alfabetico</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="221"/>
        <source>Sort</source>
        <translation>Ordina</translation>
    </message>
</context>
</TS>
